@@ -38,6 +38,7 @@
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-scores.c>
 #include <libgames-support/games-scores-dialog.h>
+#include <libgames-support/games-sound.h>
 #include <libgames-support/games-stock.h>
 
 #ifdef WITH_SMCLIENT
@@ -95,17 +96,11 @@ GtkAction *resume_action;
 
 /*GstElement *sound_player;*/
 
-static const GamesScoresCategory scorecats[] = { {"Small", N_("Small")},
-{"Medium", N_("gnomine|Medium")},
-{"Large", N_("Large")},
-{"Custom", N_("Custom")},
-GAMES_SCORES_LAST_CATEGORY
-};
-
-static const GamesScoresDescription scoredesc = { scorecats,
-  "Small",
-  APP_NAME,
-  GAMES_SCORES_STYLE_TIME_ASCENDING
+static const GamesScoresCategory scorecats[] = {
+  {"Small",  NC_("board size", "Small")  },
+  {"Medium", NC_("board size", "Medium") },
+  {"Large",  NC_("board size", "Large")  },
+  {"Custom", NC_("board size", "Custom") }
 };
 
 GamesScores *highscores;
@@ -654,6 +649,8 @@ create_preferences (void)
   GtkWidget *overmine_toggle;
   GtkWidget *xentry;
   GtkWidget *yentry;
+  GSList *group;
+  int i;
 
   table = gtk_table_new (3, 2, FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (table), 5);
@@ -664,41 +661,20 @@ create_preferences (void)
 
   vbox = gtk_vbox_new (FALSE, 6);
 
-  button = gtk_radio_button_new_with_label (NULL, _("Small"));
-  if (fsize == 0)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-  g_signal_connect (GTK_OBJECT (button), "clicked",
-		    G_CALLBACK (size_radio_callback),
-		    GINT_TO_POINTER (0));
-  gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+  group = NULL;
+  for (i = 0; i < G_N_ELEMENTS (scorecats); ++i) {
+    button = gtk_radio_button_new_with_label (group, g_dpgettext2 (NULL, "board size", scorecats[i].name));
+    if (fsize == i) {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+    }
 
-  button = gtk_radio_button_new_with_label
-    (gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)),
-     Q_ ("gnomine|Medium"));
-  if (fsize == 1)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-  g_signal_connect (GTK_OBJECT (button), "clicked",
-		    G_CALLBACK (size_radio_callback),
-		    GINT_TO_POINTER (1));
-  gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    g_signal_connect (GTK_OBJECT (button), "clicked",
+                      G_CALLBACK (size_radio_callback),
+                      GINT_TO_POINTER (i));
+    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
-  button = gtk_radio_button_new_with_label
-    (gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), _("Large"));
-  if (fsize == 2)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-  g_signal_connect (GTK_OBJECT (button), "clicked",
-		    G_CALLBACK (size_radio_callback),
-		    GINT_TO_POINTER (2));
-  gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-
-  button = gtk_radio_button_new_with_label
-    (gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), _("Custom"));
-  if (fsize == 3)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-  g_signal_connect (GTK_OBJECT (button), "clicked",
-		    G_CALLBACK (size_radio_callback),
-		    GINT_TO_POINTER (3));
-  gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (button));
+  }
 
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
@@ -992,22 +968,11 @@ main (int argc, char *argv[])
     {NULL}
   };
 
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
-   * calling any glib functions.
-   */
-  g_thread_init (NULL);
-#endif
-
   if (!games_runtime_init ("gnomine"))
     return 1;
 
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
   context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
@@ -1016,6 +981,7 @@ main (int argc, char *argv[])
 #ifdef WITH_SMCLIENT
   g_option_context_add_group (context, egg_sm_client_get_option_group ());
 #endif /* WITH_SMCLIENT */
+  games_sound_add_option_group (context);
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
@@ -1030,9 +996,11 @@ main (int argc, char *argv[])
     
   games_conf_initialise (APP_NAME);
 
-  highscores = games_scores_new (&scoredesc);
-
-  /* sound_init (&argc, &argv); */
+  highscores = games_scores_new (APP_NAME,
+                                 scorecats, G_N_ELEMENTS (scorecats),
+                                 "board size", NULL,
+                                 0 /* default category */,
+                                 GAMES_SCORES_STYLE_TIME_ASCENDING);
 
   g_signal_connect (games_conf_get_default (), "value-changed",
                     G_CALLBACK (conf_value_changed_cb), NULL);
